@@ -1,6 +1,6 @@
-SpGeoCod <- function(x, y, areanames = "", occ.thresh = 0, elevation = FALSE, threshold) {
+SpGeoCod <- function(x, y, areanames = "", occ.thresh = 0, elevation = FALSE, threshold, cleaning = FALSE, ...) {
     if (elevation == TRUE){
-      ini <- ReadPoints(x, y)
+      ini <- ReadPoints(x, y, cleaning = cleaning, ...)
       coords <- data.frame(identifier = ini$identifier, 
                            ini$species_coordinates)
       coords$ele <- GetElevation(coords)
@@ -18,13 +18,13 @@ SpGeoCod <- function(x, y, areanames = "", occ.thresh = 0, elevation = FALSE, th
       tt <- split(coords, coords$cuts)
   
       tt <- lapply(tt, function(x) .adjFormat(x))
-      ini <- lapply(tt, function(x) ReadPoints(x, y))
+      ini <- lapply(tt, function(x) ReadPoints(x, y, cleaning = cleaning, ...))
       outo <- lapply(ini, function(x) SpGeoCodH(x, areanames, occ.thresh = occ.thresh))
       names(outo) <- gsub(">", "over_", names(outo))
       names(outo) <- paste(names(outo), "_meters", sep = "")
       return(outo)
     }else{    
-      ini <- ReadPoints(x, y)
+      ini <- ReadPoints(x, y, cleaning = cleaning, ...)
       outo <- SpGeoCodH(ini, areanames, occ.thresh = occ.thresh)
     return(outo)
     }
